@@ -48,11 +48,22 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  The size of the image read is verified.
         """
-        path = ir.files("tests.data").joinpath("oj-ht-byte.jph")
+        path = ir.files("tests.data.from-openjpeg").joinpath("oj-ht-byte.jph")
         j = Jp2k(path)
         d = j[:]
         self.assertEqual(d.shape, (20, 20))
 
+    def test_tilesize_property(self):
+        """
+        Scenario:  open existing jp2 in read-write mode
+
+        Expected response:  the tilesize is reported, is not None
+        """
+        j = Jp2k(self.jp2file)
+        actual = j.tilesize
+        expected = 1456, 2592
+        self.assertEqual(actual, expected)
+
     def test_repr(self):
         """
         Scenario:  run repr on Jp2k object
@@ -102,7 +113,7 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  the dtype property is np.uint16
         """
-        path = ir.files("tests.data").joinpath("uint16.j2k")
+        path = ir.files("tests.data.misc").joinpath("uint16.j2k")
         j = Jp2k(path)
         self.assertEqual(j.dtype, np.uint16)
 
@@ -123,17 +134,17 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  the dtype property is np.int8
         """
-        path = ir.files("tests.data").joinpath("p0_03.j2k")
+        path = ir.files("tests.data.conformance").joinpath("p0_03.j2k")
         j = Jp2k(path)
         self.assertEqual(j.dtype, np.int8)
 
-    def test_dtype_inconsistent_bitdetph(self):
+    def test_dtype_inconsistent_bitdepth(self):
         """
         Scenario:  The image has different bitdepths in different components.
 
         Expected response:  TypeError when accessing the dtype property.
         """
-        path = ir.files("tests.data").joinpath("issue392.jp2")
+        path = ir.files("tests.data.from-openjpeg").joinpath("issue392.jp2")
 
         with warnings.catch_warnings():
             # There's a warning due to an unrecognized colorspace.  Don't care
@@ -168,7 +179,7 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  the ndim attribute/property is 2
         """
-        path = ir.files("tests.data").joinpath("p0_02.j2k")
+        path = ir.files("tests.data.conformance").joinpath("p0_02.j2k")
         j = Jp2k(path)
         self.assertEqual(j.ndim, 2)
 
@@ -179,7 +190,7 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESPONSE: The image is a list of arrays of unequal size.
         """
-        path = ir.files("tests.data").joinpath("p0_06.j2k")
+        path = ir.files("tests.data.conformance").joinpath("p0_06.j2k")
         d = Jp2k(path).read_bands()
 
         actual = [band.shape for band in d]
@@ -375,7 +386,7 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESULT:  RuntimeError
         """
-        path = ir.files("tests.data").joinpath("nemo.txt")
+        path = ir.files("tests.data.misc").joinpath("nemo.txt")
         with self.assertRaises(InvalidJp2kError):
             Jp2k(path)
 
@@ -883,7 +894,7 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESULT:  The 2nd image read in is not the same as the first.
         """
-        path = ir.files("tests.data").joinpath("p0_03.j2k")
+        path = ir.files("tests.data.conformance").joinpath("p0_03.j2k")
         j = Jp2k(path)
         d0 = j[:]
 
@@ -900,7 +911,7 @@ class TestJp2k(fixtures.TestCommon):
         EXPECTED RESULT:  RuntimeError when an invalid layer number is supplied
         """
         # There are 8 layers, so only values [0-7] are valid.
-        path = ir.files("tests.data").joinpath("p0_03.j2k")
+        path = ir.files("tests.data.conformance").joinpath("p0_03.j2k")
         j = Jp2k(path)
 
         with self.assertRaises(ValueError):
